command
module
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Jul 18, 2022
License: GPL-3.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
browsolate
A badly-named tool for opening multiple isolated instances of Chrome. ALL AT THE SAME TIME.
How do?
Use it from your shell
browsolate https://google.com
Or from your go
package main
import (
"fmt"
"github.com/patricksanders/browsolate"
)
func main() {
opts := &browsolate.InstanceOpts{ChromePath: "/usr/bin/chrome"}
err := browsolate.StartIsolatedChromeInstance("https://google.com", opts)
if err != nil {
fmt.Print(err)
}
}
(but you probably shouldn't because I just threw it together)
Documentation
¶
There is no documentation for this package.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.